-- 1 up
create sequence "uid_seq" start 100000;

create table "users" (
    "id" integer not null default nextval('uid_seq'),
    "uuid" varchar(36) not null,
    "username" text,
    "name" text,
    "token" text,
    primary key("id"),
    unique("uuid"),
    unique("token")
);

create table "streams" (
    "id" integer not null default nextval('uid_seq'),
    "is_active" bool not null default true,
    "is_public" bool not null default true,
    "key" text,
    "name" text,
    "publish_user_id" integer,
    "publish_last" timestamp(0),
    "publish_time" integer,
    primary key("id"),
    unique("key")
);

create table "acl" (
    "id" integer not null default nextval('uid_seq'),
    "stream_id" integer not null,
    "class" text,
    "value" text,
    primary key("id"),
    foreign key ("stream_id") references "streams" ("id") on update cascade on delete cascade
);

create view "streams_view" as
select "streams".*,
    extract(epoch from now()-"publish_last") as "publish_last_age",
    "users"."name" as "publish_user_name"
from "streams"
left join "users" on ("streams"."publish_user_id" = "users"."id")
;

-- 1 down
drop view "streams_view";
drop table "acl";
drop table "streams";
drop table "users";
drop sequence "uid_seq";

-- 2 up
alter table "streams" add "description" text;
