const path = require('path');
var webpack = require('webpack');

module.exports = {
    entry: {
        default: './src/index.js',
    },
    output: {
        filename: 'bundle.js',
        path: path.resolve(__dirname, 'public')
    },
    module: {
        noParse: [
            /node_modules\/video.js\/dist\/video.min.js/,
            /node_modules\/videojs-contrib-quality-levels\/dist\/videojs-contrib-quality-levels.min.js/,
            /node_modules\/videojs-hls-quality-selector\/dist\/videojs-hls-quality-selector.min.js/
        ],

        rules: [
            {
                test: /\.(woff(2)?|ttf|eot|svg)(\?v=[0-9]\.[0-9]\.[0-9])?$/,
                loader: 'url-loader',
                options: {
                    limit: 8192,
                    name:'[name].[ext]',
                    outputPath:'/fonts' //the icons will be stored in dist/assets folder
                }
            },

            {
                test: /\.(png|jpg|gif)$/,
                 use: [
                    {
                        loader: 'file-loader',
                        options: {}
                    }
                ]
            },


            {
                test: /\.css$/,
                use: ['style-loader', 'css-loader']
            },


            {
                test: /\.(scss)$/,
                use: [
                    {
                        // Adds CSS to the DOM by injecting a `<style>` tag
                        loader: 'style-loader'
                    },
                    {
                        // Interprets `@import` and `url()` like `import/require()` and will resolve them
                        loader: 'css-loader'
                    },
                    {
                        // Loader for webpack to process CSS with PostCSS
                        loader: 'postcss-loader',
                        options: {
                            plugins: function () {
                                return [ require('autoprefixer')  ];
                            }
                        }
                    },
                    {
                        // Loads a SASS/SCSS file and compiles it to CSS
                        loader: 'sass-loader'
                    }
                ]
            },
        ],
    },
    plugins: [
        new webpack.ProvidePlugin({
            $: 'jquery',
            jQuery: 'jquery',
        })
    ],
};



